==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/TLSMatchAttributesFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.util.LinkedHashMap;
import java.lang.Integer;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface TLSMatchAttributesFluent<A extends TLSMatchAttributesFluent<A>> extends Fluent<A>{


    public A addToDestinationSubnets(int index,String item);
    public A setToDestinationSubnets(int index,String item);
    public A addToDestinationSubnets(String... items);
    public A addAllToDestinationSubnets(Collection<String> items);
    public A removeFromDestinationSubnets(String... items);
    public A removeAllFromDestinationSubnets(Collection<String> items);
    public List<String> getDestinationSubnets();
    public String getDestinationSubnet(int index);
    public String getFirstDestinationSubnet();
    public String getLastDestinationSubnet();
    public String getMatchingDestinationSubnet(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withDestinationSubnets(List<String> destinationSubnets);
    public A withDestinationSubnets(String... destinationSubnets);
    public Boolean hasDestinationSubnets();
    public A addToGateways(int index,String item);
    public A setToGateways(int index,String item);
    public A addToGateways(String... items);
    public A addAllToGateways(Collection<String> items);
    public A removeFromGateways(String... items);
    public A removeAllFromGateways(Collection<String> items);
    public List<String> getGateways();
    public String getGateway(int index);
    public String getFirstGateway();
    public String getLastGateway();
    public String getMatchingGateway(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withGateways(List<String> gateways);
    public A withGateways(String... gateways);
    public Boolean hasGateways();
    public Integer getPort();
    public A withPort(Integer port);
    public Boolean hasPort();
    public A withNewPort(String arg1);
    public A withNewPort(int arg1);
    public A addToSniHosts(int index,String item);
    public A setToSniHosts(int index,String item);
    public A addToSniHosts(String... items);
    public A addAllToSniHosts(Collection<String> items);
    public A removeFromSniHosts(String... items);
    public A removeAllFromSniHosts(Collection<String> items);
    public List<String> getSniHosts();
    public String getSniHost(int index);
    public String getFirstSniHost();
    public String getLastSniHost();
    public String getMatchingSniHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withSniHosts(List<String> sniHosts);
    public A withSniHosts(String... sniHosts);
    public Boolean hasSniHosts();
    public A addToSourceLabels(String key,String value);
    public A addToSourceLabels(Map<String,String> map);
    public A removeFromSourceLabels(String key);
    public A removeFromSourceLabels(Map<String,String> map);
    public Map<String,String> getSourceLabels();
    public A withSourceLabels(Map<String,String> sourceLabels);
    public Boolean hasSourceLabels();
    public String getSourceSubnet();
    public A withSourceSubnet(String sourceSubnet);
    public Boolean hasSourceSubnet();



}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/TLSMatchAttributesFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface TLSMatchAttributesFluent<A extends TLSMatchAttributesFluent<A>> extends Fluent<A>{


    public A addToDestinationSubnets(int index,String item);
    public A setToDestinationSubnets(int index,String item);
    public A addToDestinationSubnets(String... items);
    public A addAllToDestinationSubnets(Collection<String> items);
    public A removeFromDestinationSubnets(String... items);
    public A removeAllFromDestinationSubnets(Collection<String> items);
    public List<String> getDestinationSubnets();
    public String getDestinationSubnet(int index);
    public String getFirstDestinationSubnet();
    public String getLastDestinationSubnet();
    public String getMatchingDestinationSubnet(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingDestinationSubnet(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withDestinationSubnets(List<String> destinationSubnets);
    public A withDestinationSubnets(String... destinationSubnets);
    public Boolean hasDestinationSubnets();
    public A addNewDestinationSubnet(String arg1);
    public A addNewDestinationSubnet(StringBuilder arg1);
    public A addNewDestinationSubnet(StringBuffer arg1);
    public A addToGateways(int index,String item);
    public A setToGateways(int index,String item);
    public A addToGateways(String... items);
    public A addAllToGateways(Collection<String> items);
    public A removeFromGateways(String... items);
    public A removeAllFromGateways(Collection<String> items);
    public List<String> getGateways();
    public String getGateway(int index);
    public String getFirstGateway();
    public String getLastGateway();
    public String getMatchingGateway(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingGateway(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withGateways(List<String> gateways);
    public A withGateways(String... gateways);
    public Boolean hasGateways();
    public A addNewGateway(String arg1);
    public A addNewGateway(StringBuilder arg1);
    public A addNewGateway(StringBuffer arg1);
    public Integer getPort();
    public A withPort(Integer port);
    public Boolean hasPort();
    public A addToSniHosts(int index,String item);
    public A setToSniHosts(int index,String item);
    public A addToSniHosts(String... items);
    public A addAllToSniHosts(Collection<String> items);
    public A removeFromSniHosts(String... items);
    public A removeAllFromSniHosts(Collection<String> items);
    public List<String> getSniHosts();
    public String getSniHost(int index);
    public String getFirstSniHost();
    public String getLastSniHost();
    public String getMatchingSniHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingSniHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withSniHosts(List<String> sniHosts);
    public A withSniHosts(String... sniHosts);
    public Boolean hasSniHosts();
    public A addNewSniHost(String arg1);
    public A addNewSniHost(StringBuilder arg1);
    public A addNewSniHost(StringBuffer arg1);
    public A addToSourceLabels(String key,String value);
    public A addToSourceLabels(Map<String,String> map);
    public A removeFromSourceLabels(String key);
    public A removeFromSourceLabels(Map<String,String> map);
    public Map<String,String> getSourceLabels();
    public A withSourceLabels(Map<String,String> sourceLabels);
    public Boolean hasSourceLabels();
    public String getSourceSubnet();
    public A withSourceSubnet(String sourceSubnet);
    public Boolean hasSourceSubnet();
    public A withNewSourceSubnet(String arg1);
    public A withNewSourceSubnet(StringBuilder arg1);
    public A withNewSourceSubnet(StringBuffer arg1);



}
